#ifndef __LOGFILE_H__
#define __LOGFILE_H__

const DWORD      DefaultLineBuffSize = 1024;
const LPCTSTR    DefaultLogFile      = TEXT(".\\LogFile.txt");

class CLogFile
{
private:
    HANDLE              m_hLogFile;// Ot@Cnh
    CRITICAL_SECTION    m_cs;// NeBJZNV

public:
    CLogFile(void)
    {
        m_hLogFile = INVALID_HANDLE_VALUE;
        InitializeCriticalSection(&m_cs);
    }

    ~CLogFile(void)
    {
        StopLog();
        DeleteCriticalSection(&m_cs);
    }
LRESULT StartLog(LPCTSTR lpctszLogFileName = DefaultLogFile)
    {
        if(m_hLogFile != INVALID_HANDLE_VALUE){
            StopLog();
        }
        if(lpctszLogFileName == NULL){
            lpctszLogFileName = DefaultLogFile;
        }

        m_hLogFile = CreateFile(lpctszLogFileName,
                GENERIC_WRITE, FILE_SHARE_READ,
                NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, NULL);
        if(m_hLogFile == INVALID_HANDLE_VALUE){
            return GetLastError();
        }
        SetFilePointer(m_hLogFile, 0, 0, FILE_END);

        return ERROR_SUCCESS;
    }

    void StopLog(void)
    {
        if(m_hLogFile != INVALID_HANDLE_VALUE){
            CloseHandle(m_hLogFile);
        }
        m_hLogFile = INVALID_HANDLE_VALUE;
    }
void PrintLog(LPCTSTR lpctszFormat, ...)
    {
        if(m_hLogFile == INVALID_HANDLE_VALUE){
            return;
        }

        SYSTEMTIME    stime;
        LPTSTR        *lplptszParam = ((LPTSTR*)&lpctszFormat) + 1;
        DWORD        dwWritten = 0L;

        LPTSTR    lptszFormatLineBuff = new TCHAR[DefaultLineBuffSize];
        LPTSTR    lptszLineBuff       = new TCHAR[DefaultLineBuffSize];

        GetLocalTime(&stime);
        wvsprintf(lptszFormatLineBuff, lpctszFormat, (LPTSTR)lplptszParam);
        wsprintf(lptszLineBuff, "%04d/%02d/%02d %02d:%02d:%02d %04x %s\r\n",
            stime.wYear, stime.wMonth, stime.wDay,
            stime.wHour, stime.wMinute, stime.wSecond,
            GetCurrentThreadId(), lptszFormatLineBuff);
        delete lptszFormatLineBuff;

        EnterCriticalSection(&m_cs);

        WriteFile(m_hLogFile,
                lptszLineBuff, lstrlen(lptszLineBuff), &dwWritten, NULL);
        delete lptszLineBuff;
        FlushFileBuffers(m_hLogFile);
        SetFilePointer(m_hLogFile, 0, 0, FILE_END);

        LeaveCriticalSection(&m_cs);
	}




};

#endif    /* __LOGFILE_H__ */
